{% if filetype_loop == 0 %}VRF,Association Address,Delay,Configured,Local Mode,Offset,Poll,Reach,Receive Time,Reference ID,Stratum{% for vrf in to_parse_ntp %}{% for address in to_parse_ntp[vrf].associations.address %}{% for is_conf,value in to_parse_ntp[vrf].associations.address[address].local_mode.client.isconfigured.items() %}
{{ vrf }},{{ address }},{{ value.delay }},{{ value.isconfigured }},{{ value.local_mode }},{{ value.offset }},{{ value.poll }},{{ value.reach }},{{ value.receive_time }},{{ value.refid }},{{ value.stratum }}{% endfor %}{% endfor %}{% endfor %}{% else %}{% if filetype_loop == 1 %}
# Learn NTP Associations
| VRF | Association Address | Delay | Configured | Local Mode | Offset | Poll | Reach | Receive Time | Reference ID | Stratum |
| --- | ------------------- | ----- | ---------- | ---------- | ------ | ---- | ----- | ------------ | ------------ | ------- | {% for vrf in to_parse_ntp %}{% for address in to_parse_ntp[vrf].associations.address %}{% for is_conf,value in to_parse_ntp[vrf].associations.address[address].local_mode.client.isconfigured.items() %}
| {{ vrf }} | {{ address }} | {{ value.delay }} | {{ value.isconfigured }} | {{ value.local_mode }} | {{ value.offset }} | {{ value.poll }} | {{ value.reach }} | {{ value.receive_time }} | {{ value.refid }} | {{ value.stratum }} |{% endfor %}{% endfor %}{% endfor %}{% else %}{% if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>Learn NTP Associations</h1>
<table id = "ntp">
  <tr>
    <th>VRF</th>
    <th>Association Address</th>
    <th>Delay</th><th>Configured</th>
    <th>Local Mode</th>
    <th>Offset</th>
    <th>Poll</th>
    <th>Reach</th>
    <th>Receive Time</th>
    <th>Reference ID</th>
    <th>Stratum</th>
  </tr>{% for vrf in to_parse_ntp %}{% for address in to_parse_ntp[vrf].associations.address %}{% for is_conf,value in to_parse_ntp[vrf].associations.address[address].local_mode.client.isconfigured.items() %}
<tr>
    <td>{{ vrf }}</td>
    <td>{{ address }}</td>
    <td>{{ value.delay }}</td>
    <td>{{ value.isconfigured }}</td>
    <td>{{ value.local_mode }}</td>
    <td>{{ value.offset }}</td>
    <td>{{ value.poll }}</td>
    <td>{{ value.reach }}</td>
    <td>{{ value.receive_time }}</td>
    <td>{{ value.refid }}</td>
    <td>{{ value.stratum }}</td>    
  </tr>{% endfor %}{% endfor %}{% endfor %}
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#ntp thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#ntp thead');

    var table = $('#ntp').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>
{%- else %}
# Learn NTP Associations
## VRF
{% for vrf in to_parse_ntp %}
### {{ vrf }}
{%     for address in to_parse_ntp[vrf].associations.address %}
#### Address {{ address }}
{%         for is_conf,value in to_parse_ntp[vrf].associations.address[address].local_mode.client.isconfigured.items() %}
##### Delay: {{ value.delay }}
##### Is Configured: {{ value.isconfigured }}
##### Local Mode: {{ value.local_mode }}
##### Offset: {{ value.offset }}
##### Poll: {{ value.poll }}
##### Reach: {{ value.reach }}
##### Receive Time: {{ value.receive_time }}
##### Reference ID: {{ value.refid }}
##### Statum: {{ value.stratum }}
{%         endfor %}
{%     endfor %}
{% endfor %}
{% endif %}{% endif %}{% endif %}